Service Layer Traits
Core traits that define the service layer interfaces for Thread. These traits abstract over ast-grep functionality while preserving all its powerful capabilities and enabling codebase-level intelligence.
Re-exports
pub use analyzer::AnalysisPerformanceProfile;pub use analyzer::AnalyzerCapabilities;pub use analyzer::CodeAnalyzer;pub use parser::CodeParser;pub use parser::ParserCapabilities;